@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmMclocCodeUtils.cc 10313 2020-02-01 22:30:08Z dwm $
+// @(#) $Id: DwmMclocCodeUtils.cc 11196 2020-11-07 06:56:09Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2019
 //  All rights reserved.
@@ -68,7 +68,7 @@
 
 using namespace std;
 
-static const string svnid("@(#) $DwmPath: dwm/mcplex/mcloc/tags/mcloc-1.0.1/DwmMclocCodeUtils.cc 10313 $");
+static const string svnid("@(#) $DwmPath: dwm/mcplex/mcloc/tags/mcloc-1.0.2/DwmMclocCodeUtils.cc 11196 $");
 
 namespace Dwm {
 
@@ -185,6 +185,12 @@ namespace Dwm {
                                          get<1>(p)); });
           rc = (it != g_regexLanguageMap.end());
         }
+        if (rc) {
+          static regex   shlib(".+\\.so(\\.[0-9]+)*",
+                               regex::ECMAScript | regex::optimize);
+          rc = (! regex_match(fspath.filename().string(), shlib));
+        }
+
         return rc;
       }
 
