@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmMclocSourceCollection.cc 10315 2020-02-02 06:41:57Z dwm $
+// @(#) $Id: DwmMclocSourceCollection.cc 11195 2020-11-07 06:50:24Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2019
 //  All rights reserved.
@@ -60,7 +60,7 @@ extern "C" {
 
 using namespace std;
 
-static const string svnid("@(#) $DwmPath: dwm/mcplex/mcloc/tags/mcloc-1.0.1/DwmMclocSourceCollection.cc 10315 $");
+static const string svnid("@(#) $DwmPath: dwm/mcplex/mcloc/tags/mcloc-1.0.2/DwmMclocSourceCollection.cc 11195 $");
 
 namespace Dwm {
 
@@ -233,7 +233,11 @@ namespace Dwm {
         oss << " (" << f->second.GeneratedBy().string() << ")";
       }
       string  s(oss.str());
-      string  trailer(tt.Columns() - (s.size() + 3), ' ');
+      int  trailerSize = tt.Columns() - (s.size() + 3);
+      string  trailer;
+      if (trailerSize > 0) {
+        trailer.assign(trailerSize, ' ');
+      }
       tt.Underscore(os, true);
       os << s << trailer;
       tt.Underscore(os, false);
@@ -387,14 +391,15 @@ namespace Dwm {
       auto it = _sources.find(fspath);
       if (it == _sources.end()) {
         unique_ptr<SourceDirFiles>  newFiles = make_unique<SourceDirFiles>();
-        
-        for (auto & di : fs::directory_iterator(fspath)) {
-          if (fs::is_regular_file(di.path())) {
-            newFiles->AddFile(di.path());
+        fs::directory_iterator  di(fspath);
+        fs::directory_iterator  dirEnd;
+        for ( ; di != dirEnd; ++di) {
+          if (fs::is_regular_file(di->path())) {
+            newFiles->AddFile(di->path());
           }
-          else if (recurse && (! fs::is_symlink(di.path()))
-                   && fs::is_directory(di.path())) {
-            AddDirectory(di.path(), recurse);
+          else if (recurse && (! fs::is_symlink(di->path()))
+                   && fs::is_directory(di->path())) {
+            AddDirectory(di->path(), recurse);
           }
         }
         if (! newFiles->Files().empty()) {
@@ -681,7 +686,11 @@ namespace Dwm {
               << setw(11) << dirTotals[d->first].CommentLines() << ' '
               << d->first;
           string  s(oss.str());
-          string  trailer(tt.Columns() - (s.size() + 3), ' ');
+          int  trailerSize = tt.Columns() - (s.size() + 3);
+          string  trailer;
+          if (trailerSize > 0) {
+            trailer.assign(trailerSize, ' ');
+          }
           os << "D " << tt.Underscore(s + trailer) << '\n';
         }
       }
