@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: mcloc.cc 10360 2020-02-24 04:09:15Z dwm $
+// @(#) $Id: mcloc.cc 11194 2020-11-07 06:48:24Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2019, 2020
 //  All rights reserved.
@@ -39,6 +39,8 @@
 //!  \brief count lines of code in file(s) and/or directories
 //---------------------------------------------------------------------------
 
+#include <filesystem>
+#include <iostream>
 extern "C" {
   #include <unistd.h>
 }
@@ -53,7 +55,7 @@ extern "C" {
 
 using namespace std;
 
-static const string g_svnid("@(#) $DwmPath: dwm/mcplex/mcloc/tags/mcloc-1.0.1/mcloc.cc 10360 $");
+static const string g_svnid("@(#) $DwmPath: dwm/mcplex/mcloc/tags/mcloc-1.0.2/mcloc.cc 11194 $");
 
 static const string g_defaultConf("/usr/local/etc/mcloc.cfg");
 
@@ -77,7 +79,7 @@ static string SupportedLanguages()
   using namespace Dwm::Mcloc;
 
   string          rc;
-  vector<string>     languages;
+  vector<string>  languages;
   Config::Config  config;
   if (config.Parse(g_defaultConf)) {
     string  sep;
@@ -135,7 +137,7 @@ typedef   Dwm::Arguments<Dwm::Argument<'C',bool>,
                          Dwm::Argument<'o',bool>,
                          Dwm::Argument<'q',bool>,
                          Dwm::Argument<'a',bool>,
-                         Dwm::Argument<'r',bool>>  MyArgType;
+                         Dwm::Argument<'r',bool>> MyArgType;
 
 //----------------------------------------------------------------------------
 //!  
@@ -164,6 +166,9 @@ static void InitArgs(MyArgType & args, const std::string & configPath)
   args.SetHelp<'s'>("print counters by scanner type");
   args.SetHelp<'g'>("include generated files");
   args.Set<'j'>(thread::hardware_concurrency());
+  if (args.Get<'j'>() > 24) {
+    args.Set<'j'>(args.Get<'j'>() / 2);
+  }
   args.SetValueName<'j'>("numThreads");
   args.SetHelp<'j'>("specify the number of parsing threads (default "
                     + to_string(args.Get<'j'>()) + ")");
